# WebVid

WebVid-10M is a large-scale dataset of short videos with textual descriptions
sourced from the web. The videos are diverse and rich in their content.

WebVid-10M contains:

* 10.7M video-caption pairs.
* 52K total video hours.

During processing, videos are converted to a fixed resolution, framerate,
and duration. Videos that fail to be processed are dropped.
